==> config-0.1.18.jar: antistock/config/test.clj <==
(ns antistock.config.test
  (:require [antistock.config.core :as core]))

(def env
  {:as-api-bind-address "0.0.0.0"
   :as-api-bind-port "33000"
   :as-api-scheme "http"
   :as-api-server-name "localhost"
   :as-api-server-port "33000"
   :as-aws-access-key "AWS-ACCESS-KEY"
   :as-aws-account-number "AWS-ACCOUNT-NUMBER"
   :as-aws-secret-key "AWS-SECRET-KEY"
   :as-broker-server-name "localhost"
   :as-broker-server-port "5672"
   :as-broker-username "tiger"
   :as-broker-password "scotch"
   :as-broker-vhost "antistock.test"
   :as-db-name "antistock_test"
   :as-db-password "scotch"
   :as-db-rollback "true"
   :as-db-scheme "postgresql"
   :as-db-server-name "localhost"
   :as-db-server-port "5432"
   :as-db-username "tiger"
   :as-google-api-key "GOOGLE-API-KEY"
   :as-google-client-id "GOOGLE-CLIENT-ID"
   :as-google-client-secret "GOOGLE-CLIENT-SECRET"
   :as-google-redirect-uri "http://localhost/oauth/google/callback"
   :as-reload-disabled "true"
   :as-spark-master "local"
   :as-spark-app-name "antistock"
   :as-twitter-access-token "TWITTER-ACCESS-TOKEN"
   :as-twitter-access-token-secret "TWITTER-ACCESS-TOKEN-SECRET"
   :as-twitter-consumer-key "TWITTER-CONSUMER-KEY"
   :as-twitter-consumer-secret "TWITTER-CONSUMER-SECRET"
   :as-web-bind-address "0.0.0.0"
   :as-web-bind-port "33001"
   :as-web-scheme "http"
   :as-web-server-name "localhost"
   :as-web-server-port "33001"
   :as-zookeeper-server-name "localhost"
   :as-zookeeper-server-port "2181"
   :as-zookeeper-username "tiger"
   :as-zookeeper-password "scotch"})

(defn config
  "Return the test config."
  [& [opts]]
  (core/config (merge env opts)))

==> config-0.1.30.jar: antistock/config/test.clj <==
(ns antistock.config.test
  (:require [antistock.config.core :as core]))

(def env
  {:as-api-bind-address "0.0.0.0"
   :as-api-bind-port "33000"
   :as-api-scheme "http"
   :as-api-server-name "localhost"
   :as-api-server-port "33000"
   :as-aws-access-key "AWS-ACCESS-KEY"
   :as-aws-account-number "AWS-ACCOUNT-NUMBER"
   :as-aws-secret-key "AWS-SECRET-KEY"
   :as-broker-server-name "localhost"
   :as-broker-server-port "5672"
   :as-broker-username "tiger"
   :as-broker-password "scotch"
   :as-broker-vhost "antistock.test"
   :as-db-name "antistock_test"
   :as-db-password "scotch"
   :as-db-test "true"
   :as-db-scheme "postgresql"
   :as-db-server-name "localhost"
   :as-db-server-port "5432"
   :as-db-username "tiger"
   :as-reload-disabled "true"
   :as-spark-master "local"
   :as-spark-app-name "antistock"
   :as-twitter-access-token
   "2925671818-BkfsoN2M0uF3QBi8q8T2oyMZIxkjy22GMhwQXKW"
   :as-twitter-access-token-secret
   "kgBev6Vqwtqt375ctrHDxddwc3zZcTqKhQvqxvtrABgoK"
   :as-twitter-consumer-key
   "Q3oTZzOeDsqwS927T1cTEbrl4"
   :as-twitter-consumer-secret
   "iICWi2Mv3WKAAi1q6TnvwWo0dmP8raREGu8YVRyoVnY2Ddx40n"
   :as-web-bind-address "0.0.0.0"
   :as-web-bind-port "33001"
   :as-web-scheme "http"
   :as-web-server-name "localhost"
   :as-web-server-port "33001"
   :as-zookeeper-server-name "localhost"
   :as-zookeeper-server-port "2181"
   :as-zookeeper-username "tiger"
   :as-zookeeper-password "scotch"})

(defn config
  "Return the test config."
  [& [opts]]
  (core/config (merge env opts)))
